@@ -37,8 +37,13 @@ class TimestreamDimensions:
     def get_dimension(self, key: str) -> str:
         return self.__dimensions.get(key)
 
-    def loadable(self) -> List[dict]:
+    def get_dimension_keys(self) -> List[str]:
+        return list(self.__dimensions.keys())
+
+    def loadable(self, omit_dimensions: List[str] = None) -> List[dict]:
         '''loadable returns a list of dictionaries that is ready to load into Timestream'''
+        omit_dimensions = omit_dimensions or []
+        assert isinstance(omit_dimensions, list)
         return [
             {
                 'Name': k,
@@ -46,6 +51,7 @@ class TimestreamDimensions:
                 'DimensionValueType': 'VARCHAR'
             }
             for k, v in self.__dimensions.items()
+            if k not in omit_dimensions
         ]
 
     def to_dict(self) -> dict:
@@ -78,3 +84,6 @@ class TimestreamDimensions:
 
     def __repr__(self) -> str:
         return json.dumps(self.to_dict())
+
+    def __len__(self) -> int:
+        return len(self.__dimensions)
