@@ -8,6 +8,7 @@ from timestream.dimensions import TimestreamDimensions
 from timestream.load_result import TimestreamLoadResult
 from timestream.record import RejectedTimestreamRecord, TimestreamRecord
 from timestream.timestream_reader import TimestreamReader
+from timestream.multi_measure import TimestreamRecordMulti
 from timestream.util import is_time_key, is_version_key
 from typing import List
 
@@ -68,7 +69,7 @@ class TimestreamLoader(TimestreamReader):
         ignore_parse_error: bool = True,
         max_batch_size: int = DEFAULT_MAX_BATCH_SIZE,
         min_common_dimensions: int = DEFAULT_MIN_COMMON_DIMENSIONS,
-        is_multi: bool = None
+        is_multi: bool = False
 
     ) -> dict:
         '''
@@ -96,7 +97,7 @@ class TimestreamLoader(TimestreamReader):
         ignore_parse_error: bool = True,
         max_batch_size: int = DEFAULT_MAX_BATCH_SIZE,
         min_common_dimensions: int = DEFAULT_MIN_COMMON_DIMENSIONS,
-        is_multi: bool = None
+        is_multi: bool = False
     ) -> dict:
         '''
         Performs a dry run of a Timestream load, including validating the input values and parsing data
@@ -125,12 +126,12 @@ class TimestreamLoader(TimestreamReader):
         preview: bool = False,
         max_batch_size: int = DEFAULT_MAX_BATCH_SIZE,
         min_common_dimensions: int = DEFAULT_MIN_COMMON_DIMENSIONS,
-        is_multi: bool = None
+        is_multi: bool = False
     ) -> TimestreamLoadResult:
         self._logger.info(f'Loading data with {len(data)} elements')
 
         # Parse incoming data into TimestreamRecords
-        result = self.__parse_data(data, upsert, ignore_parse_error)
+        result = self.__parse_data(data, upsert, ignore_parse_error, is_multi)
         if preview or result.error or len(result.accepted_records) == 0:
             return result
 
@@ -255,7 +256,7 @@ class TimestreamLoader(TimestreamReader):
         ]
         return accepted_records, rejected_records
 
-    def __parse_data(self, data: List[dict], upsert: bool, ignore_parse_error: bool) -> TimestreamLoadResult:
+    def __parse_data(self, data: List[dict], upsert: bool, ignore_parse_error: bool, is_multi: bool) -> TimestreamLoadResult:
         '''
         Parses the given data and returns a TimestreamLoadResult that contains:
           1. Successfully parsed TimestreamRecords
@@ -269,7 +270,7 @@ class TimestreamLoader(TimestreamReader):
 
         for item in data:
             try:
-                records_from_item = self.__parse_item(item, upsert, ignore_parse_error)
+                records_from_item = self.__parse_item(item, upsert, ignore_parse_error, is_multi)
             except AssertionError as e:
                 result.error = Exception('Some items could not be parsed into Timestream records')
                 result.add_invalid_item(item, e)
@@ -277,7 +278,7 @@ class TimestreamLoader(TimestreamReader):
             result.add_accepted_records(records_from_item)
         return result
 
-    def __parse_item(self, item: dict, upsert: bool, ignore_parse_error: bool) -> List[TimestreamRecord]:
+    def __parse_item(self, item: dict, upsert: bool, ignore_parse_error: bool, is_multi: bool) -> List[TimestreamRecord]:
         '''
         Parses a single dictionary into Timestream records. A single dictionary may break down into
         multiple Timestream records if there are multiple numerical values in the dictionary.
@@ -310,11 +311,16 @@ class TimestreamLoader(TimestreamReader):
                 raise AssertionError('Field "version" is a protected field and cannot exist on an item')
             elif type(v) in [float, int, list]:
                 # Ints, floats, and lists get converted into records
-                records.append(TimestreamRecord(
-                    measure_name=k,
-                    measure_value=v if type(v) in [float, int] else len(v),
-                    mstime=mstime
-                ))
+                if not is_multi:
+                    records.append(TimestreamRecord(
+                        measure_name=k,
+                        measure_value=v if type(v) in [float, int] else len(v),
+                        mstime=mstime
+                    ))
+                else:
+                    records.append({
+                        k:v
+                    })
             elif type(v) is str:
                 # Strings get converted into dimensions
                 dimensions.add_dimension(k, v)
@@ -325,12 +331,21 @@ class TimestreamLoader(TimestreamReader):
                 self._logger.warning(msg)
 
         # Recreate all records with dimensions attached and return
-        return [
-            TimestreamRecord(
-                measure_name=r.measure_name,
-                measure_value=r.measure_value,
-                dimensions=dimensions,
-                mstime=r.mstime
-            )
-            for r in records
-        ]
+        if not is_multi:
+            return [
+                TimestreamRecord(
+                    measure_name=r.measure_name,
+                    measure_value=r.measure_value,
+                    dimensions=dimensions,
+                    mstime=r.mstime
+                )
+                for r in records
+            ]
+        else:
+            return [
+                TimestreamRecordMulti(
+                    measure_values=records,
+                    dimensions=dimensions,
+                    mstime=mstime
+                )
+            ]
